@@ -509,8 +509,12 @@ class Required(BaseRule):
         self.status = False
 
     def check_value(self):
-        pass
+        try:
+            value_str = str(self.field_value).strip()
+        except ValueError:
+            value_str = ''
 
+        self.status = True if value_str else False
 
 class Accepted(BaseRule):
     name = 'accepted'
@@ -1068,7 +1072,7 @@ class PrintableASCII(BaseRule):
             self.status = self.check_string()
 
     def check_null(self):
-        self.status = False
+        self.status = True
 
     def check_string(self):
         if not self.field_value:
@@ -1160,8 +1164,12 @@ class Exist(Unique):
     def check_model(self):
         model_name, model_field = self.args
         model = self.get_model(model_name)
-        qs = model.objects.filter(**{model_field: self.field_value})
-        return qs.exists()
+        try:
+            qs = model.objects.filter(**{model_field: self.field_value})
+        except ValueError:
+            return False
+        else:
+            return qs.exists()
 
 
 class UniqueAgainst(Unique):
